#!/usr/bin/env python

import numpy as np
from roboticstoolbox.robot.ERobot import ERobot
from math import pi

class AL5D_mdw(ERobot):
    """
    Class that imports a AL5D_mdw URDF model

    ``AL5D_mdw()`` is a class which imports from a URDF file the definition
    of a Lynxmotion AL5D robot with a medium duty wrist joint. The model
    describes its kinematic and graphical characteristics.

    .. runblock:: pycon

        >>> import roboticstoolbox as rtb
        >>> robot = rtb.models.URDF.AL5D_mdw()
        >>> print(robot)

    Defined joint configurations are:

    - qz, zero joint angle configuration, 'L' shaped configuration
    - up, robot poiting upwards

    .. codeauthor:: Tassos Natsakis
    """

    def __init__(self):

        links, name, urdf_string, urdf_filepath = self.URDF_read(
            "al5d_mdw_description/urdf/al5d_mdw_robot.urdf"
        )

        super().__init__(
            links,
            name=name,
            urdf_string=urdf_string,
            urdf_filepath=urdf_filepath,
        )

        self.manufacturer = "Lynxmotion"

        # zero angles, upper arm pointing up, lower arm straight ahead
        self.addconfiguration("qz", np.array([0, 0, 0, 0, 0]))

        # reference pose robot pointing upwards
        self.addconfiguration("up", np.array([0, 0, 1.5707, 0, 0]))

if __name__ == "__main__":  # pragma nocover

    robot = AL5D_mdw()
    print(robot)
